<no title> — CALCEPH - Fortran 77/90/95 language 3.4.1 documentation

    program F90example
        implicit none
        include 'f90calceph.h'
        integer res
        double precision AU
        integer*8 :: peph

        res = f90calceph_open(peph, "example1.dat")
        if (res.eq.1) then
          write (*,*) "The ephemeris is already opened"
          if (f90calceph_getconstant(peph, "AU", AU).eq.1) then
                write (*,*) "AU=", AU
          endif
          call f90calceph_close(peph)
          write (*,*) "The ephemeris is already closed"
        endif
    stop
    end